Looper Analysis report
LOOPER
GENOME INFO
File name: ./here/there/there/there/here/left/rightHomo sapiens.fna
Genome size: 3.24GB bases
GC%: 45.4%
Sequences: 545
REPEATS INFO
Total Repeats: 4631324
Repeat bases: 69.09 Mb
Percent genome covered: 45.4
Repeat classes: 545
Frequency per Mb: 545
Base density per Mb: 545
REPEATS SUMMARY
REPEAT SUMMARY
LONGEST REPEATS
MOST UNITS
REPEAT ABUNDANCE
REPEAT ABUNDANCE
K-MER DISTRIBUTION
LENGTH vs FREQUENCY
Repeat Selection
----- OR -----
Show
Top
Top
Least
by
Frequency
Frequency
Bases
Repeats
Apply
Parameters
Percentage of Total
Data type: Bases Frequency
Min-Length: bp
Max-Length: bp